.. rst-class:: hide-header

Jinja
=====

.. image:: _static/jinja-logo.png
    :align: center
    :target: https://palletsprojects.com/p/jinja/

Jinja is a fast, expressive, extensible templating engine. Special
placeholders in the template allow writing code similar to Python
syntax. Then the template is passed data to render the final document.

.. toctree::
    :maxdepth: 2
    :caption: Contents:

    intro
    api
    sandbox
    nativetypes
    templates
    extensions
    integration
    switching
    tricks
    faq
    license
    changes
